<?php

namespace App\Admin\Controllers\OrdersManagement;

use App\Admin\Actions\backstage\Orders\Evaluate;
use App\Admin\Actions\backstage\Orders\OrderDetails;
use App\Admin\Actions\backstage\User\MapDepot;
use App\Admin\Actions\backstage\User\Suggests;
use App\Models\Order;
use App\Models\OrderPack;
use App\Models\ServicePack;
use Encore\Admin\Controllers\AdminController;
use Encore\Admin\Form;
use Encore\Admin\Grid;
use Encore\Admin\Show;

class ConsultingOrdersController extends AdminController
{
    /**
     * Title for current resource.
     *
     * @var string
     */
    protected $title = '咨询订单';

    /**
     * Make a grid builder.
     *
     * @return Grid
     */
    protected function grid()
    {
        $grid = new Grid(new Order());
        $grid->disableCreateButton();
        $grid->model()->wherein('product_type',[1,2]);
        //筛选
        $grid->filter(function ($filter){
            $filter->disableIdFilter();
            $filter->column(1/3, function ($filter) {
                $filter->like('user.nickname','用户姓名');
                $filter->equal('user_id', '用户id');
                $filter->timestampBetween('payment_time', "支付时间")->datetime();
                $filter->in('evaluate.score','评分')->checkbox([
                    1    => 1,
                    2    => 2,
                    3    => 3,
                    4    => 4,
                    5    => 5,
                ]);

            });
            $filter->column(1/3, function ($filter) {
                $filter->like('docter.name','医生姓名');
                $filter->equal('docter_id', '医生id');
                $filter->equal('product_type','产品类型')->radio(
                    [
                        ''=>'不限',
                        1=>'电话咨询',
                        2=>'图文咨询',
                    ]
                );
                $filter->timestampBetween('receiving_time', "接单时间")->datetime();
            });
            $filter->column(1/3, function ($filter) {
                $filter->like('orderPatient.name','患者姓名');
                $filter->equal('order_status','订单状态')->radio(
                    [
                        ''=>'不限',
                        1=>'未支付',
                        2=>'待接单',
                        3=>'进行中',
                        4=>'已完成',
                        5=>'已取消'
                    ]
                );
                $filter->timestampBetween('end_time', "订单完成时间")->datetime();
            });
        });
        //操作
        $grid->actions(function ($actions) {
            // 去掉删除
            $actions->disableDelete();
            // 去掉编辑
            $actions->disableEdit();
//            $actions->add(new MapDepot());
            $actions->add(new Evaluate());
//            $actions->add(new Suggests());

        });
        $grid->model()->orderBy('id','desc');
        $grid->column('id', __('Id'))->sortable();
        $grid->column('user.nickname', __('用户姓名'));
        $grid->column('docter.name', __('医生姓名'));
        $grid->column('orderPatient.name', __('患者姓名'));
        $grid->column('orderPatient.patient_phone', __('患者电话'));
        $grid->column('orderPatient.symptoms', __('患者描述'));
        $grid->column('product_type', __('产品类型'))->using([1=>'电话咨询',2=>'图文咨询']);
        $grid->column('payment_type', __('支付方式'))->display(function ($payment_type){
            if ($payment_type == 1)
            {
                return '微信支付';
            }
            if ($payment_type == 2){
                return '余额支付';
            }
            if ($payment_type == 3){
                $order_pack_id = OrderPack::where('id',$this->pay_order_pack_id)->pluck('service_pack_id');
                $name = ServicePack::where('id',$order_pack_id[0])->pluck('name');
                return '服务包支付('.$name[0].')';
            }
        });
        $grid->column('order_status', __('订单状态'))->using([1=>'未支付',2=>'待接单',3=>'进行中',4=>'已完成',5=>'已取消']);
        $grid->column('payment_status', __('支付状态'))->using([1=>'待付款',2=>'已付款',3=>'退款中',4=>'已退款']);
        $grid->column('total_amount', __('订单总金额'))->display(function ($money){
            return $money/100;
        });
        $grid->column('payment_amount', __('用户实际支付的金额'))->display(function ($money){
            return $money/100;
        });
        $grid->column('discount_amount', __('折扣金额'))->display(function ($money){
            return $money/100;
        });
        $grid->column('evaluate.score', __('订单评分'));
        $grid->column('evaluate.status', __('评分状态'))->using([1=>'待审核',2=>'审核通过',3=>'审核拒绝']);
        $grid->column('payment_time', __('支付时间'))->display(function ($time){
            return date('Y-m-d H:i:s',$time);
        });
        $grid->column('receiving_time', __('接单时间'))->display(function ($time){
            return date('Y-m-d H:i:s',$time);
        });
        $grid->column('end_time', __('订单完成时间'))->display(function ($time){
            return date('Y-m-d H:i:s',$time);
        });

        return $grid;
    }

    /**
     * Make a show builder.
     *
     * @param mixed $id
     * @return Show
     */
    protected function detail($id)
    {
        $show = new Show(Order::findOrFail($id));
        $show->field('id', __('Id'));
        $show->field('user_id', __('用户id'));
        $show->field('user.nickname', __('用户姓名'));
        $show->field('docter_id', __('医生id'));
        $show->field('docter.name', __('医生姓名'));
        $show->field('patient_id', __('患者id'));
        $show->field('orderPatient.name', __('患者姓名'));
        $show->field('organization_id', __('机构id'));
        $show->field('organization.name', __('机构名'));
        $show->field('order_sn', __('订单号'));
        $show->field('product_type', __('产品类型'))->using([1=>'电话咨询',2=>'图文咨询']);
        $show->field('payment_type', __('支付类型'))->using([1=>'微信支付',2=>'余额支付']);
        $show->field('order_status', __('订单状态'))->using([1=>'未支付',2=>'待接单',3=>'进行中',4=>'已完成',5=>'已取消']);
        $show->field('payment_status', __('支付状态'))->using([1=>'待付款',2=>'已付款',3=>'退款中',4=>'已退款']);
        $show->field('total_amount', __('	订单总金额'))->as(function ($money){
            return $money/100;
        });
        $show->field('payment_amount', __('用户实际支付的金额'))->as(function ($money){
            return $money/100;
        });
        $show->field('discount_amount', __('折扣金额'))->as(function ($money){
            return $money/100;
        });
        $show->field('payment_time', __('支付时间'))->as(function ($time){
            if($time == 0)
            {
                return '';
            }
            else
            {
                return date('Y-m-d H:i:s',$time);
            }
        });
        $show->field('receiving_time', __('接单时间'))->as(function ($time){
            if($time == 0)
            {
                return '';
            }
            else
            {
                return date('Y-m-d H:i:s',$time);
            }
        });
        $show->field('end_time', __('订单完成时间'))->as(function ($time){
            if($time == 0)
            {
                return '';
            }
            else
            {
                return date('Y-m-d H:i:s',$time);
            }
        });
        $show->field('created_at', __('创建时间'));
        $show->field('updated_at', __('更新时间'));


        return $show;
    }

    /**
     * Make a form builder.
     *
     * @return Form
     */
    protected function form()
    {
        $form = new Form(new Order());

        $form->number('user_id', __('User id'));
        $form->number('docter_id', __('Docter id'));
        $form->number('patient_id', __('Patient id'));
        $form->number('organization_id', __('Organization id'));
        $form->text('order_sn', __('Order sn'));
        $form->switch('payment_type', __('Payment type'))->default(1);
        $form->switch('product_type', __('Product type'))->default(1);
        $form->switch('order_status', __('Order status'))->default(1);
        $form->switch('payment_status', __('Payment status'))->default(1);
        $form->number('total_amount', __('Total amount'));
        $form->number('payment_amount', __('Payment amount'));
        $form->number('discount_amount', __('Discount amount'));
        $form->number('payment_time', __('Payment time'));
        $form->number('outtime', __('Outtime'));
        $form->number('receiving_time', __('Receiving time'));

        return $form;
    }
}
