<?php

namespace App\Admin\Controllers\UserManagement\DocterManagement;

use App\Admin\Actions\backstage\Docters\AddLabel;
use App\Admin\Actions\backstage\Docters\DelLabel;
use App\Admin\Actions\backstage\Docters\LabelManagement;
use App\Admin\Actions\backstage\Docters\ServiceManagement;
use App\Admin\Actions\backstage\Docters\SignUp;
use App\Admin\Actions\backstage\Docters\Team;
use App\Models\Docter;
use App\Models\DocterLabel;
use App\Models\DocterOrganization;
use App\Models\Organization;
use App\Models\User;
use Encore\Admin\Controllers\AdminController;
use Encore\Admin\Form;
use Encore\Admin\Grid;
use Encore\Admin\Show;

class DoctorManagementController extends AdminController
{
    /**
     * Title for current resource.
     *
     * @var string
     */
    protected $title = '医生列表';

    /**
     * Make a grid builder.
     *
     * @return Grid
     */
    protected function grid()
    {
        $grid = new Grid(new Docter());
        $grid->disableCreateButton();
        $grid->filter(function ($filter){
            $filter->disableIdFilter();
            $filter->like('name','昵称');
//            $filter->like('organization','机构名称');
            $filter->where(function ($query) {
                $query->whereHas('organization',function ($query){
                    $query->where('name','like',"%{$this->input}%");
                });
            },'机构名');
            $filter->equal('status','工作状态')->select([
                0    => '禁用',
                1    => '启用',
            ]);
        });
        $grid->actions(function ($actions) {
            // 去掉编辑
            $actions->disableEdit();
            // 去掉查看
            $actions->disableView();
            //签约管理
            $actions->add(new SignUp());
            //团队管理
            $actions->add(new Team());
            //标签管理
            $actions->add(new LabelManagement());
            //服务管理
            $actions->add(new ServiceManagement());
        });
        $grid->model()->orderBy('id','desc');
        $grid->column('id', __('Id'))->sortable();
        $grid->column('name', __('姓名'));
        $grid->column('avatar', __('头像'))->lightbox(['width' =>'', 'height' => 30]);
        $grid->column('phone', __('电话'));
        $grid->column('score', __('评分'));
        $grid->column('service_persons', __('服务人数'));
        $grid->column('is_then', __('认证状态'))->using([0=>'未认证',1=>'已认证']);
        $states = [
            'on'  => ['value' => 1, 'text' => '启用', 'color' => 'primary'],
            'off' => ['value' => 0, 'text' => '禁用', 'color' => 'danger'],
        ];
//        $grid->column('organization', __('所属机构'))->pluck('name')->label('info');
        $grid->column('organization', __('所属机构'))->pluck('name')->display(function ($organization){
//            dd($organization);
            if (empty($organization->toArray()))
            {
                return '无';
            }
            else
            {
                return $organization;
            }
        })->label('info');
        $grid->column('serviceapply', __('开通服务'))->where('status',2)->pluck('service_type')->display(function ($type){
//            dd($type);
            $type_arr = [];
            foreach ($type as $value)
            {
                if ($value == 1)
                {
                    array_push($type_arr,'图文');
                }
                if ($value == 2)
                {
                    array_push($type_arr,'电话');
                }
                if ($value == 3)
                {
                    array_push($type_arr,'门诊');
                }
            }
            if($type_arr==null)
            {
                return '无';
            }
            return $type_arr;
        })->label('info');
        $grid->column('label', __('标签'))->display(function ($label){
            if($label==null)
            {
                return '无';
            }
            if($label = '无'){
                return '无';
            }
            $label_value = DocterLabel::whereIn('id',$label)->where('status',1)->pluck('label_name')->toArray();
            return $label_value;
        })->label('info');
        $grid->column('status', __('工作状态'))->switch($states);
        return $grid;
    }
    /**
     * Make a show builder.
     *
     * @param mixed $id
     * @return Show
     */
    protected function detail($id)
    {
        $show = new Show(Docter::findOrFail($id));
        return $show;
    }

    /**
     * Make a form builder.
     *
     * @return Form
     */
    protected function form()
    {
        $form = new Form(new Docter());
        $form->switch('status', __('状态'));
        return $form;
    }
}
